=======
History
=======

1.0.1 (2020-04-21)
------------------

* [BUG-FIX] Update regex for triples parsing (handle escaped chars in Literals).

1.0.0 (2020-03-30)
------------------

* Add support for .ttl file without prefixes only.
* Writing to ES using native ES-Spark library.
* Params can be read from env vars.
* Redirect files are optional.
* Update docs and make code citable.

0.1.0 (2020-01-14)
------------------

* First release on PyPI.
